pub enum RyzenAdjError {
InitError {
errno: Errno,
},
InitTableError(i32),
GetNaN,
UnknowFamily(i32),
AdjFamilyNotSupported,
AdjMemoryAccessError,
AdjSmuRejected,
AdjSmuTimeout,
AdjSmuUnsupported,
AdjUnknowError(i32),
AdjValueOutOfRange,
}Expand description
Enumerates the possible errors returned from ryzenadj
Variants
InitError
ryzenadj struct init failed, provides errno returned by the library
InitTableError(i32)
this error is returned when ryzenadj can not read out values from msr, setting values might still work
GetNaN
reading given value returned a NaN float
UnknowFamily(i32)
given cpu family is not supported by this crate
AdjFamilyNotSupported
given cpu family is not supported by ryzenadj
AdjMemoryAccessError
ryzenadj encured a memory access error
AdjSmuRejected
the cpu smu rejected the given value
AdjSmuTimeout
the cpu smu timeout out when trying to set the value
AdjSmuUnsupported
the cpu smu responed with setting this value is unsupported
AdjUnknowError(i32)
unknow error ocured when tring to set give value
AdjValueOutOfRange
given value is out of allowed range